# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.batch_jobs.v1 import batch_jobs_v1_pb2 as strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2


class BatchJobsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetBatchJob = channel.unary_unary(
                '/strmprivacy.api.batch_jobs.v1.BatchJobsService/GetBatchJob',
                request_serializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.GetBatchJobRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.GetBatchJobResponse.FromString,
                )
        self.ListBatchJobs = channel.unary_unary(
                '/strmprivacy.api.batch_jobs.v1.BatchJobsService/ListBatchJobs',
                request_serializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.ListBatchJobsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.ListBatchJobsResponse.FromString,
                )
        self.CreateBatchJob = channel.unary_unary(
                '/strmprivacy.api.batch_jobs.v1.BatchJobsService/CreateBatchJob',
                request_serializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.CreateBatchJobRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.CreateBatchJobResponse.FromString,
                )
        self.DeleteBatchJob = channel.unary_unary(
                '/strmprivacy.api.batch_jobs.v1.BatchJobsService/DeleteBatchJob',
                request_serializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.DeleteBatchJobRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.DeleteBatchJobResponse.FromString,
                )
        self.UpdateBatchJobState = channel.unary_unary(
                '/strmprivacy.api.batch_jobs.v1.BatchJobsService/UpdateBatchJobState',
                request_serializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.UpdateBatchJobStateRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.UpdateBatchJobStateResponse.FromString,
                )


class BatchJobsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetBatchJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBatchJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBatchJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBatchJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBatchJobState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BatchJobsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJob,
                    request_deserializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.GetBatchJobRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.GetBatchJobResponse.SerializeToString,
            ),
            'ListBatchJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBatchJobs,
                    request_deserializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.ListBatchJobsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.ListBatchJobsResponse.SerializeToString,
            ),
            'CreateBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBatchJob,
                    request_deserializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.CreateBatchJobRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.CreateBatchJobResponse.SerializeToString,
            ),
            'DeleteBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBatchJob,
                    request_deserializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.DeleteBatchJobRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.DeleteBatchJobResponse.SerializeToString,
            ),
            'UpdateBatchJobState': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBatchJobState,
                    request_deserializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.UpdateBatchJobStateRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.UpdateBatchJobStateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.batch_jobs.v1.BatchJobsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BatchJobsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.batch_jobs.v1.BatchJobsService/GetBatchJob',
            strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.GetBatchJobRequest.SerializeToString,
            strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.GetBatchJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBatchJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.batch_jobs.v1.BatchJobsService/ListBatchJobs',
            strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.ListBatchJobsRequest.SerializeToString,
            strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.ListBatchJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.batch_jobs.v1.BatchJobsService/CreateBatchJob',
            strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.CreateBatchJobRequest.SerializeToString,
            strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.CreateBatchJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.batch_jobs.v1.BatchJobsService/DeleteBatchJob',
            strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.DeleteBatchJobRequest.SerializeToString,
            strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.DeleteBatchJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBatchJobState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.batch_jobs.v1.BatchJobsService/UpdateBatchJobState',
            strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.UpdateBatchJobStateRequest.SerializeToString,
            strmprivacy_dot_api_dot_batch__jobs_dot_v1_dot_batch__jobs__v1__pb2.UpdateBatchJobStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/monitoring/v1/monitoring.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.strmprivacy/api/monitoring/v1/monitoring.proto\x12\x1dstrmprivacy.api.monitoring.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe9\x01\n\x15GetEntityStateRequest\x12@\n\x03ref\x18\x01 \x01(\x0b\x32..strmprivacy.api.monitoring.v1.EntityState.RefR\x03ref\x12I\n\x06status\x18\x02 \x01(\x0e\x32\x31.strmprivacy.api.monitoring.v1.EntityState.StatusR\x06status\x12\x43\n\x0fprojection_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\x0eprojectionMask\"Z\n\x16GetEntityStateResponse\x12@\n\x05state\x18\x01 \x01(\x0b\x32*.strmprivacy.api.monitoring.v1.EntityStateR\x05state\"\xf0\x01\n\x1cGetLatestEntityStatesRequest\x12@\n\x03ref\x18\x01 \x01(\x0b\x32..strmprivacy.api.monitoring.v1.EntityState.RefR\x03ref\x12I\n\x06status\x18\x02 \x01(\x0e\x32\x31.strmprivacy.api.monitoring.v1.EntityState.StatusR\x06status\x12\x43\n\x0fprojection_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\x0eprojectionMask\"a\n\x1dGetLatestEntityStatesResponse\x12@\n\x05state\x18\x01 \x03(\x0b\x32*.strmprivacy.api.monitoring.v1.EntityStateR\x05state\"_\n\x19UpdateEntityStatesRequest\x12\x42\n\x06states\x18\x01 \x03(\x0b\x32*.strmprivacy.api.monitoring.v1.EntityStateR\x06states\"\x1c\n\x1aUpdateEntityStatesResponse\"\xb7\x08\n\x0b\x45ntityState\x12>\n\nstate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x02R\tstateTime\x12\x45\n\x03ref\x18\x02 \x01(\x0b\x32..strmprivacy.api.monitoring.v1.EntityState.RefB\x03\xe0\x41\x02R\x03ref\x12N\n\x06status\x18\x03 \x01(\x0e\x32\x31.strmprivacy.api.monitoring.v1.EntityState.StatusB\x03\xe0\x41\x02R\x06status\x12\x18\n\x07message\x18\x04 \x01(\tR\x07message\x12\x12\n\x04logs\x18\x05 \x03(\tR\x04logs\x12\\\n\rresource_type\x18\x06 \x01(\x0e\x32\x37.strmprivacy.api.monitoring.v1.EntityState.ResourceTypeR\x0cresourceType\x1a\x88\x01\n\x03Ref\x12I\n\x04type\x18\x01 \x01(\x0e\x32\x35.strmprivacy.api.monitoring.v1.EntityState.EntityTypeR\x04type\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\"w\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07HEALTHY\x10\x01\x12\x0b\n\x07REMOVED\x10\x02\x12\x0b\n\x07PENDING\x10\x03\x12\x0f\n\x0bTERMINATING\x10\x04\x12\r\n\tUNHEALTHY\x10\x05\x12\x0e\n\nRESTARTING\x10\x06\"\x80\x01\n\nEntityType\x12\x1b\n\x17\x45NTITY_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tBATCH_JOB\x10\x01\x12\n\n\x06STREAM\x10\x02\x12\x12\n\x0e\x42\x41TCH_EXPORTER\x10\x03\x12\x12\n\x0e\x44\x41TA_CONNECTOR\x10\x04\x12\x12\n\x0eKAFKA_EXPORTER\x10\x05\"\xbd\x02\n\x0cResourceType\x12\x1d\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x11\n\rBATCH_JOB_JOB\x10\x64\x12\x14\n\x10\x42\x41TCH_JOB_SECRET\x10\x65\x12\x18\n\x14\x42\x41TCH_JOB_CONFIG_MAP\x10\x66\x12\x10\n\x0cSTREAM_TOPIC\x10x\x12 \n\x1cSTREAM_ENCRYPTION_KEYS_TOPIC\x10y\x12\x1f\n\x1bSTREAM_DECRYPTER_DEPLOYMENT\x10z\x12\x1e\n\x19\x42\x41TCH_EXPORTER_DEPLOYMENT\x10\x8c\x01\x12\x1a\n\x15\x42\x41TCH_EXPORTER_SECRET\x10\x8d\x01\x12\x1a\n\x15\x44\x41TA_CONNECTOR_SECRET\x10\x96\x01\x12\x1e\n\x19KAFKA_EXPORTER_DEPLOYMENT\x10\xa0\x01\x32\xb7\x03\n\x11MonitoringService\x12\x7f\n\x0eGetEntityState\x12\x34.strmprivacy.api.monitoring.v1.GetEntityStateRequest\x1a\x35.strmprivacy.api.monitoring.v1.GetEntityStateResponse0\x01\x12\x92\x01\n\x15GetLatestEntityStates\x12;.strmprivacy.api.monitoring.v1.GetLatestEntityStatesRequest\x1a<.strmprivacy.api.monitoring.v1.GetLatestEntityStatesResponse\x12\x8b\x01\n\x12UpdateEntityStates\x12\x38.strmprivacy.api.monitoring.v1.UpdateEntityStatesRequest\x1a\x39.strmprivacy.api.monitoring.v1.UpdateEntityStatesResponse(\x01\x42o\n io.strmprivacy.api.monitoring.v1P\x01ZIgithub.com/strmprivacy/api-definitions-go/v2/api/monitoring/v1;monitoringb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.monitoring.v1.monitoring_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.strmprivacy.api.monitoring.v1P\001ZIgithub.com/strmprivacy/api-definitions-go/v2/api/monitoring/v1;monitoring'
  _ENTITYSTATE_REF.fields_by_name['project_id']._options = None
  _ENTITYSTATE_REF.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _ENTITYSTATE.fields_by_name['state_time']._options = None
  _ENTITYSTATE.fields_by_name['state_time']._serialized_options = b'\340A\002'
  _ENTITYSTATE.fields_by_name['ref']._options = None
  _ENTITYSTATE.fields_by_name['ref']._serialized_options = b'\340A\002'
  _ENTITYSTATE.fields_by_name['status']._options = None
  _ENTITYSTATE.fields_by_name['status']._serialized_options = b'\340A\002'
  _GETENTITYSTATEREQUEST._serialized_start=182
  _GETENTITYSTATEREQUEST._serialized_end=415
  _GETENTITYSTATERESPONSE._serialized_start=417
  _GETENTITYSTATERESPONSE._serialized_end=507
  _GETLATESTENTITYSTATESREQUEST._serialized_start=510
  _GETLATESTENTITYSTATESREQUEST._serialized_end=750
  _GETLATESTENTITYSTATESRESPONSE._serialized_start=752
  _GETLATESTENTITYSTATESRESPONSE._serialized_end=849
  _UPDATEENTITYSTATESREQUEST._serialized_start=851
  _UPDATEENTITYSTATESREQUEST._serialized_end=946
  _UPDATEENTITYSTATESRESPONSE._serialized_start=948
  _UPDATEENTITYSTATESRESPONSE._serialized_end=976
  _ENTITYSTATE._serialized_start=979
  _ENTITYSTATE._serialized_end=2058
  _ENTITYSTATE_REF._serialized_start=1350
  _ENTITYSTATE_REF._serialized_end=1486
  _ENTITYSTATE_STATUS._serialized_start=1488
  _ENTITYSTATE_STATUS._serialized_end=1607
  _ENTITYSTATE_ENTITYTYPE._serialized_start=1610
  _ENTITYSTATE_ENTITYTYPE._serialized_end=1738
  _ENTITYSTATE_RESOURCETYPE._serialized_start=1741
  _ENTITYSTATE_RESOURCETYPE._serialized_end=2058
  _MONITORINGSERVICE._serialized_start=2061
  _MONITORINGSERVICE._serialized_end=2500
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.batch_exporters.v1 import batch_exporters_v1_pb2 as strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2


class BatchExportersServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListBatchExporters = channel.unary_unary(
                '/strmprivacy.api.batch_exporters.v1.BatchExportersService/ListBatchExporters',
                request_serializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.ListBatchExportersRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.ListBatchExportersResponse.FromString,
                )
        self.GetBatchExporter = channel.unary_unary(
                '/strmprivacy.api.batch_exporters.v1.BatchExportersService/GetBatchExporter',
                request_serializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.GetBatchExporterRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.GetBatchExporterResponse.FromString,
                )
        self.DeleteBatchExporter = channel.unary_unary(
                '/strmprivacy.api.batch_exporters.v1.BatchExportersService/DeleteBatchExporter',
                request_serializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.DeleteBatchExporterRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.DeleteBatchExporterResponse.FromString,
                )
        self.CreateBatchExporter = channel.unary_unary(
                '/strmprivacy.api.batch_exporters.v1.BatchExportersService/CreateBatchExporter',
                request_serializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.CreateBatchExporterRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.CreateBatchExporterResponse.FromString,
                )


class BatchExportersServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListBatchExporters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchExporter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBatchExporter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBatchExporter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BatchExportersServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListBatchExporters': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBatchExporters,
                    request_deserializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.ListBatchExportersRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.ListBatchExportersResponse.SerializeToString,
            ),
            'GetBatchExporter': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchExporter,
                    request_deserializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.GetBatchExporterRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.GetBatchExporterResponse.SerializeToString,
            ),
            'DeleteBatchExporter': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBatchExporter,
                    request_deserializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.DeleteBatchExporterRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.DeleteBatchExporterResponse.SerializeToString,
            ),
            'CreateBatchExporter': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBatchExporter,
                    request_deserializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.CreateBatchExporterRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.CreateBatchExporterResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.batch_exporters.v1.BatchExportersService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BatchExportersService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListBatchExporters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.batch_exporters.v1.BatchExportersService/ListBatchExporters',
            strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.ListBatchExportersRequest.SerializeToString,
            strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.ListBatchExportersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchExporter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.batch_exporters.v1.BatchExportersService/GetBatchExporter',
            strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.GetBatchExporterRequest.SerializeToString,
            strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.GetBatchExporterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteBatchExporter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.batch_exporters.v1.BatchExportersService/DeleteBatchExporter',
            strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.DeleteBatchExporterRequest.SerializeToString,
            strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.DeleteBatchExporterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateBatchExporter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.batch_exporters.v1.BatchExportersService/CreateBatchExporter',
            strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.CreateBatchExporterRequest.SerializeToString,
            strmprivacy_dot_api_dot_batch__exporters_dot_v1_dot_batch__exporters__v1__pb2.CreateBatchExporterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_subjects/v1/data_subjects_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/data_subjects/v1/data_subjects_v1.proto\x12 strmprivacy.api.data_subjects.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/descriptor.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\xa6\x01\n\x1eListDataSubjectKeylinksRequest\x12N\n\x0f\x64\x61ta_subject_id\x18\x01 \x03(\tB&\xfa\x42#\x92\x01 \"\x1er\x1c\x32\x1a^[\\pL\\pN\\pS\\pM\\pP]{4,100}$R\rdataSubjectId\x12\x34\n\x0forganization_id\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0eorganizationId\"\x8c\x01\n\x1fListDataSubjectKeylinksResponse\x12i\n\x15\x64\x61ta_subject_keylinks\x18\x01 \x03(\x0b\x32\x35.strmprivacy.api.data_subjects.v1.DatasubjectKeylinksR\x13\x64\x61taSubjectKeylinks\"\xb4\x01\n\x1e\x41\x64\x64\x44\x61taSubjectsKeyLinksRequest\x12\'\n\nproject_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\x12i\n\x15\x64\x61ta_subject_keylinks\x18\x02 \x03(\x0b\x32\x35.strmprivacy.api.data_subjects.v1.DatasubjectKeylinksR\x13\x64\x61taSubjectKeylinks\"\xd8\x02\n\x1f\x41\x64\x64\x44\x61taSubjectsKeyLinksResponse\x12&\n\x0cstored_count\x18\x01 \x01(\x03\x42\x03\xe0\x41\x02R\x0bstoredCount\x12s\n\x06issues\x18\x02 \x03(\x0b\x32W.strmprivacy.api.data_subjects.v1.AddDataSubjectsKeyLinksResponse.AddDataSubjectsIssuesB\x02\x18\x01R\x06issues\x1a\x97\x01\n\x15\x41\x64\x64\x44\x61taSubjectsIssues\x12&\n\x0f\x64\x61ta_subject_id\x18\x01 \x01(\tR\rdataSubjectId\x12\x19\n\x08key_link\x18\x02 \x01(\tR\x07keyLink\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12\x1d\n\nissue_type\x18\x04 \x01(\tR\tissueType:\x02\x18\x01\"\xe8\x02\n\x13\x44\x61tasubjectKeylinks\x12I\n\x0f\x64\x61ta_subject_id\x18\x01 \x01(\tB!\xfa\x42\x1er\x1c\x32\x1a^[\\pL\\pN\\pS\\pM\\pP]{4,100}$R\rdataSubjectId\x12\x81\x01\n\x17keylinks_and_timestamps\x18\x02 \x03(\x0b\x32I.strmprivacy.api.data_subjects.v1.DatasubjectKeylinks.KeylinkAndTimestampR\x15keylinksAndTimestamps\x1a\x81\x01\n\x13KeylinkAndTimestamp\x12#\n\x08key_link\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x07keyLink\x12\x45\n\x0b\x65xpiry_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02\x08\x01R\nexpiryTime\"\x9d\x01\n\x19\x44\x65leteDataSubjectsRequest\x12J\n\rdata_subjects\x18\x01 \x03(\tB%\xfa\x42\"\x92\x01\x1f\"\x1dr\x1b\x32\x19^[\\pL\\pN\\pS\\pM\\pP]{4,100}R\x0c\x64\x61taSubjects\x12\x34\n\x0forganization_id\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0eorganizationId\"R\n\x1a\x44\x65leteDataSubjectsResponse\x12\x34\n\x16\x64\x65leted_keylinks_count\x18\x01 \x01(\x03R\x14\x64\x65letedKeylinksCount\"\x94\x01\n\x17ListDataSubjectsRequest\x12\x1d\n\npage_token\x18\x01 \x01(\tR\tpageToken\x12$\n\tpage_size\x18\x02 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02(\x00R\x08pageSize\x12\x34\n\x0forganization_id\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0eorganizationId\"\xee\x01\n\x18ListDataSubjectsResponse\x12o\n\rdata_subjects\x18\x01 \x03(\x0b\x32J.strmprivacy.api.data_subjects.v1.ListDataSubjectsResponse.DataSubjectInfoR\x0c\x64\x61taSubjects\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x1a\x39\n\x0f\x44\x61taSubjectInfo\x12&\n\x0f\x64\x61ta_subject_id\x18\x01 \x01(\tR\rdataSubjectId2\xf5\x04\n\x13\x44\x61taSubjectsService\x12\x9e\x01\n\x17ListDataSubjectKeylinks\x12@.strmprivacy.api.data_subjects.v1.ListDataSubjectKeylinksRequest\x1a\x41.strmprivacy.api.data_subjects.v1.ListDataSubjectKeylinksResponse\x12\x9e\x01\n\x17\x41\x64\x64\x44\x61taSubjectsKeyLinks\x12@.strmprivacy.api.data_subjects.v1.AddDataSubjectsKeyLinksRequest\x1a\x41.strmprivacy.api.data_subjects.v1.AddDataSubjectsKeyLinksResponse\x12\x8f\x01\n\x12\x44\x65leteDataSubjects\x12;.strmprivacy.api.data_subjects.v1.DeleteDataSubjectsRequest\x1a<.strmprivacy.api.data_subjects.v1.DeleteDataSubjectsResponse\x12\x89\x01\n\x10ListDataSubjects\x12\x39.strmprivacy.api.data_subjects.v1.ListDataSubjectsRequest\x1a:.strmprivacy.api.data_subjects.v1.ListDataSubjectsResponseBx\n#io.strmprivacy.api.data_subjects.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/data_subjects/v1;data_subjectsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.data_subjects.v1.data_subjects_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.data_subjects.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/data_subjects/v1;data_subjects'
  _LISTDATASUBJECTKEYLINKSREQUEST.fields_by_name['data_subject_id']._options = None
  _LISTDATASUBJECTKEYLINKSREQUEST.fields_by_name['data_subject_id']._serialized_options = b'\372B#\222\001 \"\036r\0342\032^[\\pL\\pN\\pS\\pM\\pP]{4,100}$'
  _LISTDATASUBJECTKEYLINKSREQUEST.fields_by_name['organization_id']._options = None
  _LISTDATASUBJECTKEYLINKSREQUEST.fields_by_name['organization_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _ADDDATASUBJECTSKEYLINKSREQUEST.fields_by_name['project_id']._options = None
  _ADDDATASUBJECTSKEYLINKSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._options = None
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._serialized_options = b'\030\001'
  _ADDDATASUBJECTSKEYLINKSRESPONSE.fields_by_name['stored_count']._options = None
  _ADDDATASUBJECTSKEYLINKSRESPONSE.fields_by_name['stored_count']._serialized_options = b'\340A\002'
  _ADDDATASUBJECTSKEYLINKSRESPONSE.fields_by_name['issues']._options = None
  _ADDDATASUBJECTSKEYLINKSRESPONSE.fields_by_name['issues']._serialized_options = b'\030\001'
  _DATASUBJECTKEYLINKS_KEYLINKANDTIMESTAMP.fields_by_name['key_link']._options = None
  _DATASUBJECTKEYLINKS_KEYLINKANDTIMESTAMP.fields_by_name['key_link']._serialized_options = b'\372B\005r\003\260\001\001'
  _DATASUBJECTKEYLINKS_KEYLINKANDTIMESTAMP.fields_by_name['expiry_time']._options = None
  _DATASUBJECTKEYLINKS_KEYLINKANDTIMESTAMP.fields_by_name['expiry_time']._serialized_options = b'\372B\005\262\001\002\010\001'
  _DATASUBJECTKEYLINKS.fields_by_name['data_subject_id']._options = None
  _DATASUBJECTKEYLINKS.fields_by_name['data_subject_id']._serialized_options = b'\372B\036r\0342\032^[\\pL\\pN\\pS\\pM\\pP]{4,100}$'
  _DELETEDATASUBJECTSREQUEST.fields_by_name['data_subjects']._options = None
  _DELETEDATASUBJECTSREQUEST.fields_by_name['data_subjects']._serialized_options = b'\372B\"\222\001\037\"\035r\0332\031^[\\pL\\pN\\pS\\pM\\pP]{4,100}'
  _DELETEDATASUBJECTSREQUEST.fields_by_name['organization_id']._options = None
  _DELETEDATASUBJECTSREQUEST.fields_by_name['organization_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _LISTDATASUBJECTSREQUEST.fields_by_name['page_size']._options = None
  _LISTDATASUBJECTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372B\004\032\002(\000'
  _LISTDATASUBJECTSREQUEST.fields_by_name['organization_id']._options = None
  _LISTDATASUBJECTSREQUEST.fields_by_name['organization_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _LISTDATASUBJECTKEYLINKSREQUEST._serialized_start=219
  _LISTDATASUBJECTKEYLINKSREQUEST._serialized_end=385
  _LISTDATASUBJECTKEYLINKSRESPONSE._serialized_start=388
  _LISTDATASUBJECTKEYLINKSRESPONSE._serialized_end=528
  _ADDDATASUBJECTSKEYLINKSREQUEST._serialized_start=531
  _ADDDATASUBJECTSKEYLINKSREQUEST._serialized_end=711
  _ADDDATASUBJECTSKEYLINKSRESPONSE._serialized_start=714
  _ADDDATASUBJECTSKEYLINKSRESPONSE._serialized_end=1058
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._serialized_start=907
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._serialized_end=1058
  _DATASUBJECTKEYLINKS._serialized_start=1061
  _DATASUBJECTKEYLINKS._serialized_end=1421
  _DATASUBJECTKEYLINKS_KEYLINKANDTIMESTAMP._serialized_start=1292
  _DATASUBJECTKEYLINKS_KEYLINKANDTIMESTAMP._serialized_end=1421
  _DELETEDATASUBJECTSREQUEST._serialized_start=1424
  _DELETEDATASUBJECTSREQUEST._serialized_end=1581
  _DELETEDATASUBJECTSRESPONSE._serialized_start=1583
  _DELETEDATASUBJECTSRESPONSE._serialized_end=1665
  _LISTDATASUBJECTSREQUEST._serialized_start=1668
  _LISTDATASUBJECTSREQUEST._serialized_end=1816
  _LISTDATASUBJECTSRESPONSE._serialized_start=1819
  _LISTDATASUBJECTSRESPONSE._serialized_end=2057
  _LISTDATASUBJECTSRESPONSE_DATASUBJECTINFO._serialized_start=2000
  _LISTDATASUBJECTSRESPONSE_DATASUBJECTINFO._serialized_end=2057
  _DATASUBJECTSSERVICE._serialized_start=2060
  _DATASUBJECTSSERVICE._serialized_end=2689
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.organizations.v1 import organizations_v1_pb2 as strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2


class OrganizationsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InviteUsers = channel.unary_unary(
                '/strmprivacy.api.organizations.v1.OrganizationsService/InviteUsers',
                request_serializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.InviteUsersRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.InviteUsersResponse.FromString,
                )
        self.UpdateUserRoles = channel.unary_unary(
                '/strmprivacy.api.organizations.v1.OrganizationsService/UpdateUserRoles',
                request_serializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.UpdateUserRolesRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.UpdateUserRolesResponse.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/strmprivacy.api.organizations.v1.OrganizationsService/GetUser',
                request_serializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.GetUserRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.GetUserResponse.FromString,
                )
        self.ListOrganizationMembers = channel.unary_unary(
                '/strmprivacy.api.organizations.v1.OrganizationsService/ListOrganizationMembers',
                request_serializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.ListOrganizationMembersRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.ListOrganizationMembersResponse.FromString,
                )


class OrganizationsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def InviteUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OrganizationsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InviteUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.InviteUsers,
                    request_deserializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.InviteUsersRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.InviteUsersResponse.SerializeToString,
            ),
            'UpdateUserRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserRoles,
                    request_deserializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.UpdateUserRolesRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.UpdateUserRolesResponse.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.GetUserRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.GetUserResponse.SerializeToString,
            ),
            'ListOrganizationMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationMembers,
                    request_deserializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.ListOrganizationMembersRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.ListOrganizationMembersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.organizations.v1.OrganizationsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OrganizationsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def InviteUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.organizations.v1.OrganizationsService/InviteUsers',
            strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.InviteUsersRequest.SerializeToString,
            strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.InviteUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.organizations.v1.OrganizationsService/UpdateUserRoles',
            strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.UpdateUserRolesRequest.SerializeToString,
            strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.UpdateUserRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.organizations.v1.OrganizationsService/GetUser',
            strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.GetUserRequest.SerializeToString,
            strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.GetUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.organizations.v1.OrganizationsService/ListOrganizationMembers',
            strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.ListOrganizationMembersRequest.SerializeToString,
            strmprivacy_dot_api_dot_organizations_dot_v1_dot_organizations__v1__pb2.ListOrganizationMembersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.projects.v1 import projects_v1_pb2 as strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2


class ProjectsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListProjects = channel.unary_unary(
                '/strmprivacy.api.projects.v1.ProjectsService/ListProjects',
                request_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectsResponse.FromString,
                )
        self.CreateProject = channel.unary_unary(
                '/strmprivacy.api.projects.v1.ProjectsService/CreateProject',
                request_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.CreateProjectResponse.FromString,
                )
        self.DeleteProject = channel.unary_unary(
                '/strmprivacy.api.projects.v1.ProjectsService/DeleteProject',
                request_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.DeleteProjectRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.DeleteProjectResponse.FromString,
                )
        self.GetProject = channel.unary_unary(
                '/strmprivacy.api.projects.v1.ProjectsService/GetProject',
                request_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.GetProjectRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.GetProjectResponse.FromString,
                )
        self.AddProjectMembers = channel.unary_unary(
                '/strmprivacy.api.projects.v1.ProjectsService/AddProjectMembers',
                request_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.AddProjectMembersRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.AddProjectMembersResponse.FromString,
                )
        self.RemoveProjectMembers = channel.unary_unary(
                '/strmprivacy.api.projects.v1.ProjectsService/RemoveProjectMembers',
                request_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.RemoveProjectMembersRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.RemoveProjectMembersResponse.FromString,
                )
        self.ListProjectMembers = channel.unary_unary(
                '/strmprivacy.api.projects.v1.ProjectsService/ListProjectMembers',
                request_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectMembersRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectMembersResponse.FromString,
                )


class ProjectsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListProjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddProjectMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveProjectMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProjectMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjects,
                    request_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectsResponse.SerializeToString,
            ),
            'CreateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateProject,
                    request_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.CreateProjectRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.CreateProjectResponse.SerializeToString,
            ),
            'DeleteProject': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProject,
                    request_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.DeleteProjectRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.DeleteProjectResponse.SerializeToString,
            ),
            'GetProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProject,
                    request_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.GetProjectRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.GetProjectResponse.SerializeToString,
            ),
            'AddProjectMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.AddProjectMembers,
                    request_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.AddProjectMembersRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.AddProjectMembersResponse.SerializeToString,
            ),
            'RemoveProjectMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveProjectMembers,
                    request_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.RemoveProjectMembersRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.RemoveProjectMembersResponse.SerializeToString,
            ),
            'ListProjectMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjectMembers,
                    request_deserializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectMembersRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectMembersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.projects.v1.ProjectsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.projects.v1.ProjectsService/ListProjects',
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectsRequest.SerializeToString,
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.projects.v1.ProjectsService/CreateProject',
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.CreateProjectRequest.SerializeToString,
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.CreateProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.projects.v1.ProjectsService/DeleteProject',
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.DeleteProjectRequest.SerializeToString,
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.DeleteProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.projects.v1.ProjectsService/GetProject',
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.GetProjectRequest.SerializeToString,
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.GetProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddProjectMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.projects.v1.ProjectsService/AddProjectMembers',
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.AddProjectMembersRequest.SerializeToString,
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.AddProjectMembersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveProjectMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.projects.v1.ProjectsService/RemoveProjectMembers',
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.RemoveProjectMembersRequest.SerializeToString,
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.RemoveProjectMembersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProjectMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.projects.v1.ProjectsService/ListProjectMembers',
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectMembersRequest.SerializeToString,
            strmprivacy_dot_api_dot_projects_dot_v1_dot_projects__v1__pb2.ListProjectMembersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.event_contracts.v1 import event_contracts_v1_pb2 as strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2


class EventContractsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListEventContracts = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/ListEventContracts',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsResponse.FromString,
                )
        self.GetEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/GetEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractResponse.FromString,
                )
        self.CreateEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/CreateEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractResponse.FromString,
                )
        self.UpdateEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/UpdateEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractResponse.FromString,
                )
        self.ActivateEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/ActivateEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractResponse.FromString,
                )
        self.DeleteEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/DeleteEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractResponse.FromString,
                )
        self.ArchiveEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/ArchiveEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractResponse.FromString,
                )
        self.ValidateMaskedFields = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/ValidateMaskedFields',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsResponse.FromString,
                )
        self.GetEventContractAndSchema = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/GetEventContractAndSchema',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaResponse.FromString,
                )


class EventContractsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListEventContracts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArchiveEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateMaskedFields(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEventContractAndSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventContractsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListEventContracts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEventContracts,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsResponse.SerializeToString,
            ),
            'GetEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractResponse.SerializeToString,
            ),
            'CreateEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractResponse.SerializeToString,
            ),
            'UpdateEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractResponse.SerializeToString,
            ),
            'ActivateEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractResponse.SerializeToString,
            ),
            'DeleteEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractResponse.SerializeToString,
            ),
            'ArchiveEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ArchiveEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractResponse.SerializeToString,
            ),
            'ValidateMaskedFields': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateMaskedFields,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsResponse.SerializeToString,
            ),
            'GetEventContractAndSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEventContractAndSchema,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.event_contracts.v1.EventContractsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EventContractsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListEventContracts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/ListEventContracts',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/GetEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/CreateEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/UpdateEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/ActivateEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/DeleteEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArchiveEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/ArchiveEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateMaskedFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/ValidateMaskedFields',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEventContractAndSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/GetEventContractAndSchema',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.installations.v1 import installed_components_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2


class InstalledComponentsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpdateInstalledComponentState = channel.unary_unary(
                '/strmprivacy.api.installations.v1.InstalledComponentsService/UpdateInstalledComponentState',
                request_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.UpdateInstalledComponentStateRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.UpdateInstalledComponentStateResponse.FromString,
                )
        self.GetInstalledComponent = channel.unary_unary(
                '/strmprivacy.api.installations.v1.InstalledComponentsService/GetInstalledComponent',
                request_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.GetInstalledComponentRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.GetInstalledComponentResponse.FromString,
                )
        self.ListInstalledComponents = channel.unary_unary(
                '/strmprivacy.api.installations.v1.InstalledComponentsService/ListInstalledComponents',
                request_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsResponse.FromString,
                )
        self.ListInstalledComponentsCurrentStates = channel.unary_unary(
                '/strmprivacy.api.installations.v1.InstalledComponentsService/ListInstalledComponentsCurrentStates',
                request_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsCurrentStatesRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsCurrentStatesResponse.FromString,
                )


class InstalledComponentsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def UpdateInstalledComponentState(self, request, context):
        """Authentication goes through the installations realm; a strm-installation-id is required in the metadata.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstalledComponent(self, request, context):
        """Authentication goes through the users realm; a strm-external-user-id is required in the metadata.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInstalledComponents(self, request, context):
        """Authentication goes through the users realm; a strm-external-user-id is required in the metadata.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInstalledComponentsCurrentStates(self, request, context):
        """Authentication goes through the users realm; a strm-external-user-id is required in the metadata. Similar to list,
        but only lists the state of the instances in the last x minutes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InstalledComponentsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpdateInstalledComponentState': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateInstalledComponentState,
                    request_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.UpdateInstalledComponentStateRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.UpdateInstalledComponentStateResponse.SerializeToString,
            ),
            'GetInstalledComponent': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstalledComponent,
                    request_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.GetInstalledComponentRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.GetInstalledComponentResponse.SerializeToString,
            ),
            'ListInstalledComponents': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInstalledComponents,
                    request_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsResponse.SerializeToString,
            ),
            'ListInstalledComponentsCurrentStates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInstalledComponentsCurrentStates,
                    request_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsCurrentStatesRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsCurrentStatesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.installations.v1.InstalledComponentsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InstalledComponentsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def UpdateInstalledComponentState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.installations.v1.InstalledComponentsService/UpdateInstalledComponentState',
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.UpdateInstalledComponentStateRequest.SerializeToString,
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.UpdateInstalledComponentStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstalledComponent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.installations.v1.InstalledComponentsService/GetInstalledComponent',
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.GetInstalledComponentRequest.SerializeToString,
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.GetInstalledComponentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListInstalledComponents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.installations.v1.InstalledComponentsService/ListInstalledComponents',
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsRequest.SerializeToString,
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListInstalledComponentsCurrentStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.installations.v1.InstalledComponentsService/ListInstalledComponentsCurrentStates',
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsCurrentStatesRequest.SerializeToString,
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installed__components__v1__pb2.ListInstalledComponentsCurrentStatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.data_contracts.v1 import data_contracts_v1_pb2 as strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2


class DataContractsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataContracts = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/ListDataContracts',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsResponse.FromString,
                )
        self.GetDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractResponse.FromString,
                )
        self.CreateDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/CreateDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractResponse.FromString,
                )
        self.UpdateDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/UpdateDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractResponse.FromString,
                )
        self.ReviewDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/ReviewDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractResponse.FromString,
                )
        self.ActivateDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/ActivateDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractResponse.FromString,
                )
        self.DeleteDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/DeleteDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractResponse.FromString,
                )
        self.ArchiveDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/ArchiveDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractResponse.FromString,
                )
        self.GetDataContractSchemaCode = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContractSchemaCode',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeResponse.FromString,
                )
        self.GetDataContractSchemaDefinition = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContractSchemaDefinition',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionResponse.FromString,
                )
        self.ValidateDataContractsMaskedFields = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/ValidateDataContractsMaskedFields',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsResponse.FromString,
                )
        self.SimpleSchemaDryRun = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/SimpleSchemaDryRun',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunResponse.FromString,
                )


class DataContractsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataContracts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReviewDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArchiveDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataContractSchemaCode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataContractSchemaDefinition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateDataContractsMaskedFields(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SimpleSchemaDryRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataContractsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataContracts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataContracts,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsResponse.SerializeToString,
            ),
            'GetDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractResponse.SerializeToString,
            ),
            'CreateDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractResponse.SerializeToString,
            ),
            'UpdateDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractResponse.SerializeToString,
            ),
            'ReviewDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ReviewDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractResponse.SerializeToString,
            ),
            'ActivateDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractResponse.SerializeToString,
            ),
            'DeleteDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractResponse.SerializeToString,
            ),
            'ArchiveDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ArchiveDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractResponse.SerializeToString,
            ),
            'GetDataContractSchemaCode': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataContractSchemaCode,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeResponse.SerializeToString,
            ),
            'GetDataContractSchemaDefinition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataContractSchemaDefinition,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionResponse.SerializeToString,
            ),
            'ValidateDataContractsMaskedFields': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateDataContractsMaskedFields,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsResponse.SerializeToString,
            ),
            'SimpleSchemaDryRun': grpc.unary_unary_rpc_method_handler(
                    servicer.SimpleSchemaDryRun,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.data_contracts.v1.DataContractsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataContractsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataContracts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/ListDataContracts',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/CreateDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/UpdateDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReviewDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/ReviewDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/ActivateDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/DeleteDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArchiveDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/ArchiveDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataContractSchemaCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContractSchemaCode',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataContractSchemaDefinition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContractSchemaDefinition',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateDataContractsMaskedFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/ValidateDataContractsMaskedFields',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SimpleSchemaDryRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/SimpleSchemaDryRun',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/agents/v1/batch_jobs_agent_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/agents/v1/batch_jobs_agent_v1.proto\x12\x19strmprivacy.api.agents.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"!\n\x1aGetDesiredBatchJobsRequest:\x03\xf8\x42\x00\"|\n\x1bGetDesiredBatchJobsResponse\x12]\n\x13\x65xtended_batch_jobs\x18\x01 \x03(\x0b\x32-.strmprivacy.api.entities.v1.ExtendedBatchJobR\x11\x65xtendedBatchJobs2\x9e\x01\n\x15\x42\x61tchJobsAgentService\x12\x84\x01\n\x13GetDesiredBatchJobs\x12\x35.strmprivacy.api.agents.v1.GetDesiredBatchJobsRequest\x1a\x36.strmprivacy.api.agents.v1.GetDesiredBatchJobsResponseBc\n\x1cio.strmprivacy.api.agents.v1P\x01ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agentsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.agents.v1.batch_jobs_agent_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.strmprivacy.api.agents.v1P\001ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agents'
  _GETDESIREDBATCHJOBSREQUEST._options = None
  _GETDESIREDBATCHJOBSREQUEST._serialized_options = b'\370B\000'
  _GETDESIREDBATCHJOBSREQUEST._serialized_start=154
  _GETDESIREDBATCHJOBSREQUEST._serialized_end=187
  _GETDESIREDBATCHJOBSRESPONSE._serialized_start=189
  _GETDESIREDBATCHJOBSRESPONSE._serialized_end=313
  _BATCHJOBSAGENTSERVICE._serialized_start=316
  _BATCHJOBSAGENTSERVICE._serialized_end=474
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.policies.v1 import policies_v1_pb2 as strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2


class PoliciesServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPolicies = channel.unary_unary(
                '/strmprivacy.api.policies.v1.PoliciesService/ListPolicies',
                request_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesResponse.FromString,
                )
        self.GetPolicy = channel.unary_unary(
                '/strmprivacy.api.policies.v1.PoliciesService/GetPolicy',
                request_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyResponse.FromString,
                )
        self.DeletePolicy = channel.unary_unary(
                '/strmprivacy.api.policies.v1.PoliciesService/DeletePolicy',
                request_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyResponse.FromString,
                )
        self.CreatePolicy = channel.unary_unary(
                '/strmprivacy.api.policies.v1.PoliciesService/CreatePolicy',
                request_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyResponse.FromString,
                )
        self.UpdatePolicy = channel.unary_unary(
                '/strmprivacy.api.policies.v1.PoliciesService/UpdatePolicy',
                request_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyResponse.FromString,
                )


class PoliciesServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListPolicies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PoliciesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPolicies,
                    request_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesResponse.SerializeToString,
            ),
            'GetPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPolicy,
                    request_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyResponse.SerializeToString,
            ),
            'DeletePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePolicy,
                    request_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyResponse.SerializeToString,
            ),
            'CreatePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePolicy,
                    request_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyResponse.SerializeToString,
            ),
            'UpdatePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePolicy,
                    request_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.policies.v1.PoliciesService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PoliciesService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.policies.v1.PoliciesService/ListPolicies',
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesRequest.SerializeToString,
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.policies.v1.PoliciesService/GetPolicy',
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyRequest.SerializeToString,
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.policies.v1.PoliciesService/DeletePolicy',
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyRequest.SerializeToString,
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.policies.v1.PoliciesService/CreatePolicy',
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyRequest.SerializeToString,
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.policies.v1.PoliciesService/UpdatePolicy',
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyRequest.SerializeToString,
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.installations.v1 import installations_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2


class InstallationsServiceStub(object):
    """Authentication goes through the users realm; a strm-external-user-id is required in the metadata.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetInstallation = channel.unary_unary(
                '/strmprivacy.api.installations.v1.InstallationsService/GetInstallation',
                request_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetInstallationRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetInstallationResponse.FromString,
                )
        self.ListInstallations = channel.unary_unary(
                '/strmprivacy.api.installations.v1.InstallationsService/ListInstallations',
                request_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationsResponse.FromString,
                )
        self.GetProjectInstallation = channel.unary_unary(
                '/strmprivacy.api.installations.v1.InstallationsService/GetProjectInstallation',
                request_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetProjectInstallationRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetProjectInstallationResponse.FromString,
                )
        self.ListInstallationProjects = channel.unary_unary(
                '/strmprivacy.api.installations.v1.InstallationsService/ListInstallationProjects',
                request_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationProjectsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationProjectsResponse.FromString,
                )


class InstallationsServiceServicer(object):
    """Authentication goes through the users realm; a strm-external-user-id is required in the metadata.
    """

    def GetInstallation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInstallations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjectInstallation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInstallationProjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InstallationsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetInstallation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstallation,
                    request_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetInstallationRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetInstallationResponse.SerializeToString,
            ),
            'ListInstallations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInstallations,
                    request_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationsResponse.SerializeToString,
            ),
            'GetProjectInstallation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjectInstallation,
                    request_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetProjectInstallationRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetProjectInstallationResponse.SerializeToString,
            ),
            'ListInstallationProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInstallationProjects,
                    request_deserializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationProjectsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationProjectsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.installations.v1.InstallationsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InstallationsService(object):
    """Authentication goes through the users realm; a strm-external-user-id is required in the metadata.
    """

    @staticmethod
    def GetInstallation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.installations.v1.InstallationsService/GetInstallation',
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetInstallationRequest.SerializeToString,
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetInstallationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListInstallations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.installations.v1.InstallationsService/ListInstallations',
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationsRequest.SerializeToString,
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjectInstallation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.installations.v1.InstallationsService/GetProjectInstallation',
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetProjectInstallationRequest.SerializeToString,
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.GetProjectInstallationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListInstallationProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.installations.v1.InstallationsService/ListInstallationProjects',
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationProjectsRequest.SerializeToString,
            strmprivacy_dot_api_dot_installations_dot_v1_dot_installations__v1__pb2.ListInstallationProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
